@@ -317,12 +317,18 @@ class Extractor:
                      "year": None,
                      "number": None,
                      "number_with_tail": None,
-                     "special": None}
+                     "special": None,
+                     "special_part1": None,
+                     "special_part2": None,
+                     "special_part3": None}
         org_name = None
         year = None
         number = None
         another_number = None
         query = text
+        special_part1 = None
+        special_part2 = None
+        special_part3 = None
         p = re.compile(u'[\u4e00-\u9fa5]+')
         res = re.findall(p, query)
         for part in res:
@@ -353,6 +359,12 @@ class Extractor:
                 year = res.group(1)
                 number = res.group(2)
             else:
+                res = re.search('[〔\[\(［]\s*([0-9]{4})\s*[〕\]\)］]', query)
+                if res:
+                    temp = int(res.group(1))
+                    if temp >= 1900 and temp <= 2100:
+                        final_res["document_no_full"] += res.group(0)
+                        year = res.group(1)
                 res = re.search('[第]?\s*([0-9]+)\s*(号|号文|期)', query)
                 if res:
                     final_res["document_no_full"] += res.group(0)
@@ -364,14 +376,20 @@ class Extractor:
                         final_res["document_no_full"] += res.group(0)
                         number = res.group(1)
 
-        res = re.search('[a-zA-Z]+/[a-zA-Z]+\s*[0-9]+(\.[0-9]+)?[—-][0-9]{4}', query)
+        res = re.search('([a-zA-Z]+/[a-zA-Z]+)\s*([0-9]+(\.[0-9]+)?)[—-]+([0-9]{4})', query)
         if res:
             another_number = res.group(0)
-            final_res["document_no_full"] += " " + another_number
+            final_res["document_no_full"] += ("" if final_res["document_no_full"] == "" else " ") + another_number
+            special_part1 = res.group(1)
+            special_part2 = res.group(2)
+            special_part3 = res.group(4)
         final_res["document_department_with_tail"] = org_name
         final_res["year"] = year
         final_res["number"] = number
         final_res["special"] = another_number
+        final_res["special_part1"] = special_part1
+        final_res["special_part2"] = special_part2
+        final_res["special_part3"] = special_part3
         if not final_res["number_with_tail"]:
             final_res["number_with_tail"] = number
         return final_res
@@ -434,11 +452,12 @@ class Extractor:
 
 
 
-"""
+
 if __name__ == '__main__':
     et = Extractor()
-    res = et.extract_reference_no("中国证券监督管理委员会公告〔2021〕33号")
+    res = et.extract_reference_no("〔2015〕")
     print(res)
+    exit(0)
     print(datetime.today())
     start = time.time()
     # text = "2021-03-0914:00开庭审理杨峰？"
@@ -493,4 +512,4 @@ if __name__ == '__main__':
         res = et.extract_time(text, cut_res)
         print(res)
     print((time.time() - start)/len(li))
-"""
+
